@@ -3,7 +3,13 @@ from argparse import ArgumentParser, Namespace
 from dataclasses import dataclass, field
 from typing import Union, Optional, Any, Iterable, List, Tuple
 
-__version__ = '0.3.2'
+try:
+    # Python 3.8
+    from typing import get_origin, get_args
+except ImportError:
+    from .utils import get_origin, get_args
+
+__version__ = '0.3.3'
 
 LOGGER = logging.getLogger(__name__)
 
@@ -26,6 +32,8 @@ class TypedArgs:
 
     def add_arguments(self):
         for name, annotation in self.__annotations__.items():
+            if name == 'parser':
+                continue
             self.add_argument(name, annotation)
 
     def add_argument(self, name: str, annotation: Any):
@@ -41,11 +49,31 @@ class TypedArgs:
 
         for argument_type, value in zip(types, values):
             kwargs = value.to_kwargs()
-
             args = kwargs.pop('option_strings', ())
-            kwargs['dest'] = name
+
+            kwargs['dest'] = name  # 必定有dest
+
+            is_position_argument = len(args) == 0
+
+            origin = get_origin(argument_type)
+
+            if origin is list:
+                argument_type = get_args(argument_type)[0]
+
+                print('argument type: ', argument_type)
 
             if kwargs['action'] == 'store':
+
+                # 不存在default的才需要判断optional
+                if kwargs.get('default', None) is None:
+
+                    if origin is Union:  # Optional
+                        argument_type = get_args(argument_type)[0]
+                        kwargs['required'] = False
+                    elif origin is None:
+                        if not is_position_argument:
+                            kwargs['required'] = True
+
                 kwargs['type'] = argument_type
 
             self.parser.add_argument(*args, **kwargs)
@@ -63,6 +91,8 @@ class TypedArgs:
 
     def update_arguments(self, parsed_args: Namespace):
         for name in self.__annotations__.keys():
+            if name == 'parser':
+                continue
             value = getattr(parsed_args, name)
             setattr(self, name, value)
 
@@ -93,6 +123,7 @@ class PhantomAction:
             if self.action in ['store_true', 'store_false']:
                 del kwargs['metavar']
                 del kwargs['const']
+                del kwargs['default']
 
         elif self.action == 'append_const':
             del kwargs['nargs']
